#
# spec file for package python-elastic-transport
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-elastic-transport
Version:        8.12.0
Release:        1.3
Summary:        Transport classes and utilities shared among Python Elastic client libraries
License:        Apache-2.0
URL:            https://github.com/elastic/elastic-transport-python
Source:         https://github.com/elastic/elastic-transport-python/archive/refs/tags/v%{version}.tar.gz#/elastic-transport-python-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-certifi
Requires:       python-urllib3
BuildArch:      noarch
%if 0%{python_version_nodots} < 37
Requires:       python-dataclasses
%endif
# SECTION test requirements
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module dataclasses if %python-base < 3.7}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-httpserver}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module trustme}
BuildRequires:  %{python_module urllib3}
# /SECTION
%python_subpackages

%description
Transport classes and utilities shared among Python Elastic client libraries

%prep
%setup -q -n elastic-transport-python-%{version}
sed -i '/addopts/d' setup.cfg
sed -i 's/from mock/from unittest.mock/' tests/node/test_http_*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# these tests fail without proper name resolution or online connection to httpbin.org and badssl.com
donttest="(test_http_aiohttp and not TestAiohttpHttpNode)"
donttest="$donttest or test_tls_versions"
donttest="$donttest or test_assert_fingerprint_in_cert_chain"
# gh#elastic/elastic-transport-python#96
donttest="$donttest or test_url_to_node_config[https://[::1]:0/-https://[::1]:0-]"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/elastic_transport
%{python_sitelib}/elastic_transport-%{version}*-info

%changelog
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 8.12.0:
  * Fix basic auth built from percent-encoded URLs
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 8.11.0:
  * Always set default HTTPS port to 443
  * Drop support for Python 3.6
  * Include tests in sdist
  * Fix `__iter__` return type to Iterator
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 8.10.0:
  * Support urllib3 2.x in addition to urllib3 1.26.x (#121)
  * Add 409 to `NOT_DEAD_NODE_HTTP_STATUSES` (#120)
  * Fixed an issue where a large number of consecutive failures
    to connect to a node would raise an `OverflowError`.
  * Fixed an issue to ensure that `ApiResponse` can be pickled.
* Tue May  9 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update python-urllib3 minimum requirement to build with latest
  python-urllib3
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Dec  5 2022 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken test with latest urllib3 release
  gh#elastic/elastic-transport-python#96
* Tue Sep 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 8.4.0
  * Added method for clients to use default ports for URL scheme.
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v8.3.3
- This library was lifted from elasticsearch-py and then
  transformed to be used across all Elastic services rather than
  only Elasticsearch.
